/****************************************************************************
** Meta object code from reading C++ file 'movedatafilesjob.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libktorrent-2.1/src/diskio/movedatafilesjob.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'movedatafilesjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_bt__MoveDataFilesJob_t {
    QByteArrayData data[14];
    char stringdata0[124];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_bt__MoveDataFilesJob_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_bt__MoveDataFilesJob_t qt_meta_stringdata_bt__MoveDataFilesJob = {
    {
QT_MOC_LITERAL(0, 0, 20), // "bt::MoveDataFilesJob"
QT_MOC_LITERAL(1, 21, 9), // "onJobDone"
QT_MOC_LITERAL(2, 31, 0), // ""
QT_MOC_LITERAL(3, 32, 5), // "KJob*"
QT_MOC_LITERAL(4, 38, 1), // "j"
QT_MOC_LITERAL(5, 40, 10), // "onCanceled"
QT_MOC_LITERAL(6, 51, 17), // "onRecoveryJobDone"
QT_MOC_LITERAL(7, 69, 13), // "onTransferred"
QT_MOC_LITERAL(8, 83, 3), // "job"
QT_MOC_LITERAL(9, 87, 10), // "KJob::Unit"
QT_MOC_LITERAL(10, 98, 4), // "unit"
QT_MOC_LITERAL(11, 103, 6), // "amount"
QT_MOC_LITERAL(12, 110, 7), // "onSpeed"
QT_MOC_LITERAL(13, 118, 5) // "speed"

    },
    "bt::MoveDataFilesJob\0onJobDone\0\0KJob*\0"
    "j\0onCanceled\0onRecoveryJobDone\0"
    "onTransferred\0job\0KJob::Unit\0unit\0"
    "amount\0onSpeed\0speed"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_bt__MoveDataFilesJob[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x08 /* Private */,
       5,    1,   42,    2, 0x08 /* Private */,
       6,    1,   45,    2, 0x08 /* Private */,
       7,    3,   48,    2, 0x08 /* Private */,
      12,    2,   55,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 9, QMetaType::ULongLong,    8,   10,   11,
    QMetaType::Void, 0x80000000 | 3, QMetaType::ULong,    8,   13,

       0        // eod
};

void bt::MoveDataFilesJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MoveDataFilesJob *_t = static_cast<MoveDataFilesJob *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onJobDone((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 1: _t->onCanceled((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 2: _t->onRecoveryJobDone((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 3: _t->onTransferred((*reinterpret_cast< KJob*(*)>(_a[1])),(*reinterpret_cast< KJob::Unit(*)>(_a[2])),(*reinterpret_cast< qulonglong(*)>(_a[3]))); break;
        case 4: _t->onSpeed((*reinterpret_cast< KJob*(*)>(_a[1])),(*reinterpret_cast< ulong(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            case 1:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob::Unit >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        }
    }
}

const QMetaObject bt::MoveDataFilesJob::staticMetaObject = {
    { &Job::staticMetaObject, qt_meta_stringdata_bt__MoveDataFilesJob.data,
      qt_meta_data_bt__MoveDataFilesJob,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *bt::MoveDataFilesJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *bt::MoveDataFilesJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_bt__MoveDataFilesJob.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Resource"))
        return static_cast< Resource*>(this);
    return Job::qt_metacast(_clname);
}

int bt::MoveDataFilesJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Job::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
