/****************************************************************************
** Meta object code from reading C++ file 'webseed.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libktorrent-2.1/src/download/webseed.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'webseed.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_bt__WebSeed_t {
    QByteArrayData data[15];
    char stringdata0[147];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_bt__WebSeed_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_bt__WebSeed_t qt_meta_stringdata_bt__WebSeed = {
    {
QT_MOC_LITERAL(0, 0, 11), // "bt::WebSeed"
QT_MOC_LITERAL(1, 12, 10), // "chunkReady"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 6), // "Chunk*"
QT_MOC_LITERAL(4, 31, 1), // "c"
QT_MOC_LITERAL(5, 33, 8), // "finished"
QT_MOC_LITERAL(6, 42, 20), // "chunkDownloadStarted"
QT_MOC_LITERAL(7, 63, 21), // "WebSeedChunkDownload*"
QT_MOC_LITERAL(8, 85, 2), // "cd"
QT_MOC_LITERAL(9, 88, 6), // "Uint32"
QT_MOC_LITERAL(10, 95, 5), // "chunk"
QT_MOC_LITERAL(11, 101, 21), // "chunkDownloadFinished"
QT_MOC_LITERAL(12, 123, 5), // "reset"
QT_MOC_LITERAL(13, 129, 10), // "redirected"
QT_MOC_LITERAL(14, 140, 6) // "to_url"

    },
    "bt::WebSeed\0chunkReady\0\0Chunk*\0c\0"
    "finished\0chunkDownloadStarted\0"
    "WebSeedChunkDownload*\0cd\0Uint32\0chunk\0"
    "chunkDownloadFinished\0reset\0redirected\0"
    "to_url"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_bt__WebSeed[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,
       5,    0,   47,    2, 0x06 /* Public */,
       6,    2,   48,    2, 0x06 /* Public */,
      11,    2,   53,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    0,   58,    2, 0x0a /* Public */,
      13,    1,   59,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 9,    8,   10,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 9,    8,   10,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl,   14,

       0        // eod
};

void bt::WebSeed::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        WebSeed *_t = static_cast<WebSeed *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->chunkReady((*reinterpret_cast< Chunk*(*)>(_a[1]))); break;
        case 1: _t->finished(); break;
        case 2: _t->chunkDownloadStarted((*reinterpret_cast< WebSeedChunkDownload*(*)>(_a[1])),(*reinterpret_cast< Uint32(*)>(_a[2]))); break;
        case 3: _t->chunkDownloadFinished((*reinterpret_cast< WebSeedChunkDownload*(*)>(_a[1])),(*reinterpret_cast< Uint32(*)>(_a[2]))); break;
        case 4: _t->reset(); break;
        case 5: _t->redirected((*reinterpret_cast< const QUrl(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (WebSeed::*_t)(Chunk * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WebSeed::chunkReady)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (WebSeed::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WebSeed::finished)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (WebSeed::*_t)(WebSeedChunkDownload * , Uint32 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WebSeed::chunkDownloadStarted)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (WebSeed::*_t)(WebSeedChunkDownload * , Uint32 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&WebSeed::chunkDownloadFinished)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject bt::WebSeed::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_bt__WebSeed.data,
      qt_meta_data_bt__WebSeed,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *bt::WebSeed::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *bt::WebSeed::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_bt__WebSeed.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "WebSeedInterface"))
        return static_cast< WebSeedInterface*>(this);
    return QObject::qt_metacast(_clname);
}

int bt::WebSeed::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void bt::WebSeed::chunkReady(Chunk * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void bt::WebSeed::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void bt::WebSeed::chunkDownloadStarted(WebSeedChunkDownload * _t1, Uint32 _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void bt::WebSeed::chunkDownloadFinished(WebSeedChunkDownload * _t1, Uint32 _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
