/****************************************************************************
** Meta object code from reading C++ file 'rpccall.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libktorrent-2.1/src/dht/rpccall.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'rpccall.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dht__RPCCallListener_t {
    QByteArrayData data[8];
    char stringdata0[70];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dht__RPCCallListener_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dht__RPCCallListener_t qt_meta_stringdata_dht__RPCCallListener = {
    {
QT_MOC_LITERAL(0, 0, 20), // "dht::RPCCallListener"
QT_MOC_LITERAL(1, 21, 10), // "onResponse"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 8), // "RPCCall*"
QT_MOC_LITERAL(4, 42, 1), // "c"
QT_MOC_LITERAL(5, 44, 11), // "RPCMsg::Ptr"
QT_MOC_LITERAL(6, 56, 3), // "rsp"
QT_MOC_LITERAL(7, 60, 9) // "onTimeout"

    },
    "dht::RPCCallListener\0onResponse\0\0"
    "RPCCall*\0c\0RPCMsg::Ptr\0rsp\0onTimeout"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dht__RPCCallListener[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   24,    2, 0x0a /* Public */,
       7,    1,   29,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 3,    4,

       0        // eod
};

void dht::RPCCallListener::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        RPCCallListener *_t = static_cast<RPCCallListener *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onResponse((*reinterpret_cast< RPCCall*(*)>(_a[1])),(*reinterpret_cast< RPCMsg::Ptr(*)>(_a[2]))); break;
        case 1: _t->onTimeout((*reinterpret_cast< RPCCall*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< RPCCall* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< RPCCall* >(); break;
            }
            break;
        }
    }
}

const QMetaObject dht::RPCCallListener::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_dht__RPCCallListener.data,
      qt_meta_data_dht__RPCCallListener,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *dht::RPCCallListener::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dht::RPCCallListener::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dht__RPCCallListener.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dht::RPCCallListener::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_dht__RPCCall_t {
    QByteArrayData data[9];
    char stringdata0[68];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dht__RPCCall_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dht__RPCCall_t qt_meta_stringdata_dht__RPCCall = {
    {
QT_MOC_LITERAL(0, 0, 12), // "dht::RPCCall"
QT_MOC_LITERAL(1, 13, 8), // "response"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 8), // "RPCCall*"
QT_MOC_LITERAL(4, 32, 1), // "c"
QT_MOC_LITERAL(5, 34, 11), // "RPCMsg::Ptr"
QT_MOC_LITERAL(6, 46, 3), // "rsp"
QT_MOC_LITERAL(7, 50, 7), // "timeout"
QT_MOC_LITERAL(8, 58, 9) // "onTimeout"

    },
    "dht::RPCCall\0response\0\0RPCCall*\0c\0"
    "RPCMsg::Ptr\0rsp\0timeout\0onTimeout"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dht__RPCCall[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   29,    2, 0x06 /* Public */,
       7,    1,   34,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    0,   37,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void,

       0        // eod
};

void dht::RPCCall::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        RPCCall *_t = static_cast<RPCCall *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->response((*reinterpret_cast< RPCCall*(*)>(_a[1])),(*reinterpret_cast< RPCMsg::Ptr(*)>(_a[2]))); break;
        case 1: _t->timeout((*reinterpret_cast< RPCCall*(*)>(_a[1]))); break;
        case 2: _t->onTimeout(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< RPCCall* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< RPCCall* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (RPCCall::*_t)(RPCCall * , RPCMsg::Ptr );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RPCCall::response)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (RPCCall::*_t)(RPCCall * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RPCCall::timeout)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject dht::RPCCall::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_dht__RPCCall.data,
      qt_meta_data_dht__RPCCall,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *dht::RPCCall::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dht::RPCCall::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dht__RPCCall.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dht::RPCCall::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void dht::RPCCall::response(RPCCall * _t1, RPCMsg::Ptr _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void dht::RPCCall::timeout(RPCCall * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
