/****************************************************************************
** Meta object code from reading C++ file 'magnetdownloader.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libktorrent-2.1/src/magnet/magnetdownloader.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'magnetdownloader.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_bt__MagnetDownloader_t {
    QByteArrayData data[17];
    char stringdata0[175];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_bt__MagnetDownloader_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_bt__MagnetDownloader_t qt_meta_stringdata_bt__MagnetDownloader = {
    {
QT_MOC_LITERAL(0, 0, 20), // "bt::MagnetDownloader"
QT_MOC_LITERAL(1, 21, 13), // "foundMetadata"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 21), // "bt::MagnetDownloader*"
QT_MOC_LITERAL(4, 58, 4), // "self"
QT_MOC_LITERAL(5, 63, 8), // "metadata"
QT_MOC_LITERAL(6, 72, 5), // "start"
QT_MOC_LITERAL(7, 78, 4), // "stop"
QT_MOC_LITERAL(8, 83, 9), // "onNewPeer"
QT_MOC_LITERAL(9, 93, 5), // "Peer*"
QT_MOC_LITERAL(10, 99, 1), // "p"
QT_MOC_LITERAL(11, 101, 20), // "onMetadataDownloaded"
QT_MOC_LITERAL(12, 122, 4), // "data"
QT_MOC_LITERAL(13, 127, 19), // "onTorrentDownloaded"
QT_MOC_LITERAL(14, 147, 5), // "KJob*"
QT_MOC_LITERAL(15, 153, 10), // "dhtStarted"
QT_MOC_LITERAL(16, 164, 10) // "dhtStopped"

    },
    "bt::MagnetDownloader\0foundMetadata\0\0"
    "bt::MagnetDownloader*\0self\0metadata\0"
    "start\0stop\0onNewPeer\0Peer*\0p\0"
    "onMetadataDownloaded\0data\0onTorrentDownloaded\0"
    "KJob*\0dhtStarted\0dhtStopped"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_bt__MagnetDownloader[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   54,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    0,   59,    2, 0x0a /* Public */,
       7,    0,   60,    2, 0x0a /* Public */,
       8,    1,   61,    2, 0x08 /* Private */,
      11,    1,   64,    2, 0x08 /* Private */,
      13,    1,   67,    2, 0x08 /* Private */,
      15,    0,   70,    2, 0x08 /* Private */,
      16,    0,   71,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::QByteArray,    4,    5,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, QMetaType::QByteArray,   12,
    QMetaType::Void, 0x80000000 | 14,    2,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void bt::MagnetDownloader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        MagnetDownloader *_t = static_cast<MagnetDownloader *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->foundMetadata((*reinterpret_cast< bt::MagnetDownloader*(*)>(_a[1])),(*reinterpret_cast< const QByteArray(*)>(_a[2]))); break;
        case 1: _t->start(); break;
        case 2: _t->stop(); break;
        case 3: _t->onNewPeer((*reinterpret_cast< Peer*(*)>(_a[1]))); break;
        case 4: _t->onMetadataDownloaded((*reinterpret_cast< const QByteArray(*)>(_a[1]))); break;
        case 5: _t->onTorrentDownloaded((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 6: _t->dhtStarted(); break;
        case 7: _t->dhtStopped(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< bt::MagnetDownloader* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (MagnetDownloader::*_t)(bt::MagnetDownloader * , const QByteArray & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MagnetDownloader::foundMetadata)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject bt::MagnetDownloader::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_bt__MagnetDownloader.data,
      qt_meta_data_bt__MagnetDownloader,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *bt::MagnetDownloader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *bt::MagnetDownloader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_bt__MagnetDownloader.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "TrackerDataSource"))
        return static_cast< TrackerDataSource*>(this);
    return QObject::qt_metacast(_clname);
}

int bt::MagnetDownloader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void bt::MagnetDownloader::foundMetadata(bt::MagnetDownloader * _t1, const QByteArray & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
