/****************************************************************************
** Meta object code from reading C++ file 'udptracker.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libktorrent-2.1/src/tracker/udptracker.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'udptracker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_bt__UDPTracker_t {
    QByteArrayData data[20];
    char stringdata0[214];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_bt__UDPTracker_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_bt__UDPTracker_t qt_meta_stringdata_bt__UDPTracker = {
    {
QT_MOC_LITERAL(0, 0, 14), // "bt::UDPTracker"
QT_MOC_LITERAL(1, 15, 13), // "onConnTimeout"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 15), // "connectReceived"
QT_MOC_LITERAL(4, 46, 5), // "Int32"
QT_MOC_LITERAL(5, 52, 3), // "tid"
QT_MOC_LITERAL(6, 56, 5), // "Int64"
QT_MOC_LITERAL(7, 62, 13), // "connection_id"
QT_MOC_LITERAL(8, 76, 16), // "announceReceived"
QT_MOC_LITERAL(9, 93, 12), // "const Uint8*"
QT_MOC_LITERAL(10, 106, 3), // "buf"
QT_MOC_LITERAL(11, 110, 6), // "Uint32"
QT_MOC_LITERAL(12, 117, 4), // "size"
QT_MOC_LITERAL(13, 122, 14), // "scrapeReceived"
QT_MOC_LITERAL(14, 137, 7), // "onError"
QT_MOC_LITERAL(15, 145, 12), // "error_string"
QT_MOC_LITERAL(16, 158, 17), // "onResolverResults"
QT_MOC_LITERAL(17, 176, 21), // "net::AddressResolver*"
QT_MOC_LITERAL(18, 198, 2), // "ar"
QT_MOC_LITERAL(19, 201, 12) // "manualUpdate"

    },
    "bt::UDPTracker\0onConnTimeout\0\0"
    "connectReceived\0Int32\0tid\0Int64\0"
    "connection_id\0announceReceived\0"
    "const Uint8*\0buf\0Uint32\0size\0"
    "scrapeReceived\0onError\0error_string\0"
    "onResolverResults\0net::AddressResolver*\0"
    "ar\0manualUpdate"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_bt__UDPTracker[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   49,    2, 0x08 /* Private */,
       3,    2,   50,    2, 0x08 /* Private */,
       8,    3,   55,    2, 0x08 /* Private */,
      13,    3,   62,    2, 0x08 /* Private */,
      14,    2,   69,    2, 0x08 /* Private */,
      16,    1,   74,    2, 0x08 /* Private */,
      19,    0,   77,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 6,    5,    7,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 9, 0x80000000 | 11,    5,   10,   12,
    QMetaType::Void, 0x80000000 | 4, 0x80000000 | 9, 0x80000000 | 11,    5,   10,   12,
    QMetaType::Void, 0x80000000 | 4, QMetaType::QString,    5,   15,
    QMetaType::Void, 0x80000000 | 17,   18,
    QMetaType::Void,

       0        // eod
};

void bt::UDPTracker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        UDPTracker *_t = static_cast<UDPTracker *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onConnTimeout(); break;
        case 1: _t->connectReceived((*reinterpret_cast< Int32(*)>(_a[1])),(*reinterpret_cast< Int64(*)>(_a[2]))); break;
        case 2: _t->announceReceived((*reinterpret_cast< Int32(*)>(_a[1])),(*reinterpret_cast< const Uint8*(*)>(_a[2])),(*reinterpret_cast< Uint32(*)>(_a[3]))); break;
        case 3: _t->scrapeReceived((*reinterpret_cast< Int32(*)>(_a[1])),(*reinterpret_cast< const Uint8*(*)>(_a[2])),(*reinterpret_cast< Uint32(*)>(_a[3]))); break;
        case 4: _t->onError((*reinterpret_cast< Int32(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 5: _t->onResolverResults((*reinterpret_cast< net::AddressResolver*(*)>(_a[1]))); break;
        case 6: _t->manualUpdate(); break;
        default: ;
        }
    }
}

const QMetaObject bt::UDPTracker::staticMetaObject = {
    { &Tracker::staticMetaObject, qt_meta_stringdata_bt__UDPTracker.data,
      qt_meta_data_bt__UDPTracker,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *bt::UDPTracker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *bt::UDPTracker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_bt__UDPTracker.stringdata0))
        return static_cast<void*>(this);
    return Tracker::qt_metacast(_clname);
}

int bt::UDPTracker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Tracker::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
