/****************************************************************************
** Meta object code from reading C++ file 'udptrackersocket.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libktorrent-2.1/src/tracker/udptrackersocket.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'udptrackersocket.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_bt__UDPTrackerSocket_t {
    QByteArrayData data[15];
    char stringdata0[148];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_bt__UDPTrackerSocket_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_bt__UDPTrackerSocket_t qt_meta_stringdata_bt__UDPTrackerSocket = {
    {
QT_MOC_LITERAL(0, 0, 20), // "bt::UDPTrackerSocket"
QT_MOC_LITERAL(1, 21, 15), // "connectReceived"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 5), // "Int32"
QT_MOC_LITERAL(4, 44, 3), // "tid"
QT_MOC_LITERAL(5, 48, 5), // "Int64"
QT_MOC_LITERAL(6, 54, 13), // "connection_id"
QT_MOC_LITERAL(7, 68, 16), // "announceReceived"
QT_MOC_LITERAL(8, 85, 12), // "const Uint8*"
QT_MOC_LITERAL(9, 98, 3), // "buf"
QT_MOC_LITERAL(10, 102, 6), // "Uint32"
QT_MOC_LITERAL(11, 109, 4), // "size"
QT_MOC_LITERAL(12, 114, 14), // "scrapeReceived"
QT_MOC_LITERAL(13, 129, 5), // "error"
QT_MOC_LITERAL(14, 135, 12) // "error_string"

    },
    "bt::UDPTrackerSocket\0connectReceived\0"
    "\0Int32\0tid\0Int64\0connection_id\0"
    "announceReceived\0const Uint8*\0buf\0"
    "Uint32\0size\0scrapeReceived\0error\0"
    "error_string"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_bt__UDPTrackerSocket[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   34,    2, 0x06 /* Public */,
       7,    3,   39,    2, 0x06 /* Public */,
      12,    3,   46,    2, 0x06 /* Public */,
      13,    2,   53,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 5,    4,    6,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 8, 0x80000000 | 10,    4,    9,   11,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 8, 0x80000000 | 10,    4,    9,   11,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,   14,

       0        // eod
};

void bt::UDPTrackerSocket::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        UDPTrackerSocket *_t = static_cast<UDPTrackerSocket *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->connectReceived((*reinterpret_cast< Int32(*)>(_a[1])),(*reinterpret_cast< Int64(*)>(_a[2]))); break;
        case 1: _t->announceReceived((*reinterpret_cast< Int32(*)>(_a[1])),(*reinterpret_cast< const Uint8*(*)>(_a[2])),(*reinterpret_cast< Uint32(*)>(_a[3]))); break;
        case 2: _t->scrapeReceived((*reinterpret_cast< Int32(*)>(_a[1])),(*reinterpret_cast< const Uint8*(*)>(_a[2])),(*reinterpret_cast< Uint32(*)>(_a[3]))); break;
        case 3: _t->error((*reinterpret_cast< Int32(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (UDPTrackerSocket::*_t)(Int32 , Int64 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&UDPTrackerSocket::connectReceived)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (UDPTrackerSocket::*_t)(Int32 , const Uint8 * , Uint32 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&UDPTrackerSocket::announceReceived)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (UDPTrackerSocket::*_t)(Int32 , const Uint8 * , Uint32 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&UDPTrackerSocket::scrapeReceived)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (UDPTrackerSocket::*_t)(Int32 , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&UDPTrackerSocket::error)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject bt::UDPTrackerSocket::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_bt__UDPTrackerSocket.data,
      qt_meta_data_bt__UDPTrackerSocket,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *bt::UDPTrackerSocket::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *bt::UDPTrackerSocket::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_bt__UDPTrackerSocket.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int bt::UDPTrackerSocket::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void bt::UDPTrackerSocket::connectReceived(Int32 _t1, Int64 _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void bt::UDPTrackerSocket::announceReceived(Int32 _t1, const Uint8 * _t2, Uint32 _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void bt::UDPTrackerSocket::scrapeReceived(Int32 _t1, const Uint8 * _t2, Uint32 _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void bt::UDPTrackerSocket::error(Int32 _t1, const QString & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
