/****************************************************************************
** Meta object code from reading C++ file 'httpconnection.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libktorrent-2.1/src/download/httpconnection.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'httpconnection.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_bt__HttpConnection_t {
    QByteArrayData data[11];
    char stringdata0[142];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_bt__HttpConnection_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_bt__HttpConnection_t qt_meta_stringdata_bt__HttpConnection = {
    {
QT_MOC_LITERAL(0, 0, 18), // "bt::HttpConnection"
QT_MOC_LITERAL(1, 19, 15), // "startReplyTimer"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 7), // "timeout"
QT_MOC_LITERAL(4, 44, 14), // "stopReplyTimer"
QT_MOC_LITERAL(5, 59, 16), // "stopConnectTimer"
QT_MOC_LITERAL(6, 76, 12), // "hostResolved"
QT_MOC_LITERAL(7, 89, 21), // "net::AddressResolver*"
QT_MOC_LITERAL(8, 111, 2), // "ar"
QT_MOC_LITERAL(9, 114, 14), // "connectTimeout"
QT_MOC_LITERAL(10, 129, 12) // "replyTimeout"

    },
    "bt::HttpConnection\0startReplyTimer\0\0"
    "timeout\0stopReplyTimer\0stopConnectTimer\0"
    "hostResolved\0net::AddressResolver*\0"
    "ar\0connectTimeout\0replyTimeout"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_bt__HttpConnection[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,
       4,    0,   47,    2, 0x06 /* Public */,
       5,    0,   48,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   49,    2, 0x08 /* Private */,
       9,    0,   52,    2, 0x08 /* Private */,
      10,    0,   53,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    3,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 7,    8,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void bt::HttpConnection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        HttpConnection *_t = static_cast<HttpConnection *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->startReplyTimer((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->stopReplyTimer(); break;
        case 2: _t->stopConnectTimer(); break;
        case 3: _t->hostResolved((*reinterpret_cast< net::AddressResolver*(*)>(_a[1]))); break;
        case 4: _t->connectTimeout(); break;
        case 5: _t->replyTimeout(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< net::AddressResolver* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (HttpConnection::*_t)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HttpConnection::startReplyTimer)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (HttpConnection::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HttpConnection::stopReplyTimer)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (HttpConnection::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&HttpConnection::stopConnectTimer)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject bt::HttpConnection::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_bt__HttpConnection.data,
      qt_meta_data_bt__HttpConnection,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *bt::HttpConnection::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *bt::HttpConnection::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_bt__HttpConnection.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "net::SocketReader"))
        return static_cast< net::SocketReader*>(this);
    if (!strcmp(_clname, "net::StreamSocketListener"))
        return static_cast< net::StreamSocketListener*>(this);
    return QObject::qt_metacast(_clname);
}

int bt::HttpConnection::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void bt::HttpConnection::startReplyTimer(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void bt::HttpConnection::stopReplyTimer()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void bt::HttpConnection::stopConnectTimer()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
