/****************************************************************************
** Meta object code from reading C++ file 'dhtpeersource.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libktorrent-2.1/src/dht/dhtpeersource.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dhtpeersource.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dht__DHTPeerSource_t {
    QByteArrayData data[9];
    char stringdata0[82];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dht__DHTPeerSource_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dht__DHTPeerSource_t qt_meta_stringdata_dht__DHTPeerSource = {
    {
QT_MOC_LITERAL(0, 0, 18), // "dht::DHTPeerSource"
QT_MOC_LITERAL(1, 19, 9), // "onTimeout"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 9), // "doRequest"
QT_MOC_LITERAL(4, 40, 11), // "onDataReady"
QT_MOC_LITERAL(5, 52, 5), // "Task*"
QT_MOC_LITERAL(6, 58, 1), // "t"
QT_MOC_LITERAL(7, 60, 10), // "onFinished"
QT_MOC_LITERAL(8, 71, 10) // "dhtStopped"

    },
    "dht::DHTPeerSource\0onTimeout\0\0doRequest\0"
    "onDataReady\0Task*\0t\0onFinished\0"
    "dhtStopped"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dht__DHTPeerSource[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   39,    2, 0x08 /* Private */,
       3,    0,   40,    2, 0x08 /* Private */,
       4,    1,   41,    2, 0x08 /* Private */,
       7,    1,   44,    2, 0x08 /* Private */,
       8,    0,   47,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void, 0x80000000 | 5,    6,
    QMetaType::Void,

       0        // eod
};

void dht::DHTPeerSource::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DHTPeerSource *_t = static_cast<DHTPeerSource *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->onTimeout(); break;
        case 1: { bool _r = _t->doRequest();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->onDataReady((*reinterpret_cast< Task*(*)>(_a[1]))); break;
        case 3: _t->onFinished((*reinterpret_cast< Task*(*)>(_a[1]))); break;
        case 4: _t->dhtStopped(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Task* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< Task* >(); break;
            }
            break;
        }
    }
}

const QMetaObject dht::DHTPeerSource::staticMetaObject = {
    { &bt::PeerSource::staticMetaObject, qt_meta_stringdata_dht__DHTPeerSource.data,
      qt_meta_data_dht__DHTPeerSource,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *dht::DHTPeerSource::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dht::DHTPeerSource::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dht__DHTPeerSource.stringdata0))
        return static_cast<void*>(this);
    return bt::PeerSource::qt_metacast(_clname);
}

int dht::DHTPeerSource::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = bt::PeerSource::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
