/****************************************************************************
** Meta object code from reading C++ file 'downloader.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libktorrent-2.1/src/download/downloader.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'downloader.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_bt__Downloader_t {
    QByteArrayData data[32];
    char stringdata0[324];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_bt__Downloader_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_bt__Downloader_t qt_meta_stringdata_bt__Downloader = {
    {
QT_MOC_LITERAL(0, 0, 14), // "bt::Downloader"
QT_MOC_LITERAL(1, 15, 7), // "ioError"
QT_MOC_LITERAL(2, 23, 0), // ""
QT_MOC_LITERAL(3, 24, 3), // "msg"
QT_MOC_LITERAL(4, 28, 15), // "chunkDownloaded"
QT_MOC_LITERAL(5, 44, 6), // "Uint32"
QT_MOC_LITERAL(6, 51, 5), // "chunk"
QT_MOC_LITERAL(7, 57, 6), // "update"
QT_MOC_LITERAL(8, 64, 10), // "setMonitor"
QT_MOC_LITERAL(9, 75, 17), // "MonitorInterface*"
QT_MOC_LITERAL(10, 93, 3), // "tmo"
QT_MOC_LITERAL(11, 97, 11), // "dataChecked"
QT_MOC_LITERAL(12, 109, 6), // "BitSet"
QT_MOC_LITERAL(13, 116, 9), // "ok_chunks"
QT_MOC_LITERAL(14, 126, 10), // "bt::Uint32"
QT_MOC_LITERAL(15, 137, 4), // "from"
QT_MOC_LITERAL(16, 142, 2), // "to"
QT_MOC_LITERAL(17, 145, 16), // "recalcDownloaded"
QT_MOC_LITERAL(18, 162, 13), // "pieceReceived"
QT_MOC_LITERAL(19, 176, 9), // "bt::Piece"
QT_MOC_LITERAL(20, 186, 1), // "p"
QT_MOC_LITERAL(21, 188, 8), // "finished"
QT_MOC_LITERAL(22, 197, 14), // "ChunkDownload*"
QT_MOC_LITERAL(23, 212, 1), // "c"
QT_MOC_LITERAL(24, 214, 10), // "onExcluded"
QT_MOC_LITERAL(25, 225, 10), // "onIncluded"
QT_MOC_LITERAL(26, 236, 12), // "onChunkReady"
QT_MOC_LITERAL(27, 249, 6), // "Chunk*"
QT_MOC_LITERAL(28, 256, 20), // "chunkDownloadStarted"
QT_MOC_LITERAL(29, 277, 21), // "WebSeedChunkDownload*"
QT_MOC_LITERAL(30, 299, 2), // "cd"
QT_MOC_LITERAL(31, 302, 21) // "chunkDownloadFinished"

    },
    "bt::Downloader\0ioError\0\0msg\0chunkDownloaded\0"
    "Uint32\0chunk\0update\0setMonitor\0"
    "MonitorInterface*\0tmo\0dataChecked\0"
    "BitSet\0ok_chunks\0bt::Uint32\0from\0to\0"
    "recalcDownloaded\0pieceReceived\0bt::Piece\0"
    "p\0finished\0ChunkDownload*\0c\0onExcluded\0"
    "onIncluded\0onChunkReady\0Chunk*\0"
    "chunkDownloadStarted\0WebSeedChunkDownload*\0"
    "cd\0chunkDownloadFinished"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_bt__Downloader[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      13,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   79,    2, 0x06 /* Public */,
       4,    1,   82,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   85,    2, 0x0a /* Public */,
       8,    1,   86,    2, 0x0a /* Public */,
      11,    3,   89,    2, 0x0a /* Public */,
      17,    0,   96,    2, 0x0a /* Public */,
      18,    1,   97,    2, 0x08 /* Private */,
      21,    1,  100,    2, 0x08 /* Private */,
      24,    2,  103,    2, 0x08 /* Private */,
      25,    2,  108,    2, 0x08 /* Private */,
      26,    1,  113,    2, 0x08 /* Private */,
      28,    2,  116,    2, 0x08 /* Private */,
      31,    2,  121,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    3,
    QMetaType::Void, 0x80000000 | 5,    6,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 12, 0x80000000 | 14, 0x80000000 | 14,   13,   15,   16,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 19,   20,
    QMetaType::Bool, 0x80000000 | 22,   23,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 5,   15,   16,
    QMetaType::Void, 0x80000000 | 5, 0x80000000 | 5,   15,   16,
    QMetaType::Void, 0x80000000 | 27,   23,
    QMetaType::Void, 0x80000000 | 29, 0x80000000 | 5,   30,    6,
    QMetaType::Void, 0x80000000 | 29, 0x80000000 | 5,   30,    6,

       0        // eod
};

void bt::Downloader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Downloader *_t = static_cast<Downloader *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->ioError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 1: _t->chunkDownloaded((*reinterpret_cast< Uint32(*)>(_a[1]))); break;
        case 2: _t->update(); break;
        case 3: _t->setMonitor((*reinterpret_cast< MonitorInterface*(*)>(_a[1]))); break;
        case 4: _t->dataChecked((*reinterpret_cast< const BitSet(*)>(_a[1])),(*reinterpret_cast< bt::Uint32(*)>(_a[2])),(*reinterpret_cast< bt::Uint32(*)>(_a[3]))); break;
        case 5: _t->recalcDownloaded(); break;
        case 6: _t->pieceReceived((*reinterpret_cast< const bt::Piece(*)>(_a[1]))); break;
        case 7: { bool _r = _t->finished((*reinterpret_cast< ChunkDownload*(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->onExcluded((*reinterpret_cast< Uint32(*)>(_a[1])),(*reinterpret_cast< Uint32(*)>(_a[2]))); break;
        case 9: _t->onIncluded((*reinterpret_cast< Uint32(*)>(_a[1])),(*reinterpret_cast< Uint32(*)>(_a[2]))); break;
        case 10: _t->onChunkReady((*reinterpret_cast< Chunk*(*)>(_a[1]))); break;
        case 11: _t->chunkDownloadStarted((*reinterpret_cast< WebSeedChunkDownload*(*)>(_a[1])),(*reinterpret_cast< Uint32(*)>(_a[2]))); break;
        case 12: _t->chunkDownloadFinished((*reinterpret_cast< WebSeedChunkDownload*(*)>(_a[1])),(*reinterpret_cast< Uint32(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< ChunkDownload* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Downloader::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Downloader::ioError)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Downloader::*_t)(Uint32 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Downloader::chunkDownloaded)) {
                *result = 1;
                return;
            }
        }
    }
}

const QMetaObject bt::Downloader::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_bt__Downloader.data,
      qt_meta_data_bt__Downloader,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *bt::Downloader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *bt::Downloader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_bt__Downloader.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "PieceHandler"))
        return static_cast< PieceHandler*>(this);
    return QObject::qt_metacast(_clname);
}

int bt::Downloader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void bt::Downloader::ioError(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void bt::Downloader::chunkDownloaded(Uint32 _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
