/****************************************************************************
** Meta object code from reading C++ file 'torrentcontrol.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libktorrent-2.1/src/torrent/torrentcontrol.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'torrentcontrol.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_bt__TorrentControl_t {
    QByteArrayData data[35];
    char stringdata0[374];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_bt__TorrentControl_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_bt__TorrentControl_t qt_meta_stringdata_bt__TorrentControl = {
    {
QT_MOC_LITERAL(0, 0, 18), // "bt::TorrentControl"
QT_MOC_LITERAL(1, 19, 17), // "dataCheckFinished"
QT_MOC_LITERAL(2, 37, 0), // ""
QT_MOC_LITERAL(3, 38, 6), // "update"
QT_MOC_LITERAL(4, 45, 5), // "pause"
QT_MOC_LITERAL(5, 51, 7), // "unpause"
QT_MOC_LITERAL(6, 59, 5), // "start"
QT_MOC_LITERAL(7, 65, 4), // "stop"
QT_MOC_LITERAL(8, 70, 8), // "WaitJob*"
QT_MOC_LITERAL(9, 79, 4), // "wjob"
QT_MOC_LITERAL(10, 84, 13), // "updateTracker"
QT_MOC_LITERAL(11, 98, 13), // "scrapeTracker"
QT_MOC_LITERAL(12, 112, 17), // "trackerScrapeDone"
QT_MOC_LITERAL(13, 130, 25), // "setDataCheckWhenCompleted"
QT_MOC_LITERAL(14, 156, 2), // "on"
QT_MOC_LITERAL(15, 159, 19), // "setMinimumDiskSpace"
QT_MOC_LITERAL(16, 179, 6), // "Uint32"
QT_MOC_LITERAL(17, 186, 1), // "m"
QT_MOC_LITERAL(18, 188, 9), // "onNewPeer"
QT_MOC_LITERAL(19, 198, 5), // "Peer*"
QT_MOC_LITERAL(20, 204, 1), // "p"
QT_MOC_LITERAL(21, 206, 13), // "onPeerRemoved"
QT_MOC_LITERAL(22, 220, 9), // "doChoking"
QT_MOC_LITERAL(23, 230, 9), // "onIOError"
QT_MOC_LITERAL(24, 240, 3), // "msg"
QT_MOC_LITERAL(25, 244, 11), // "updateStats"
QT_MOC_LITERAL(26, 256, 9), // "corrupted"
QT_MOC_LITERAL(27, 266, 5), // "chunk"
QT_MOC_LITERAL(28, 272, 21), // "moveDataFilesFinished"
QT_MOC_LITERAL(29, 294, 5), // "KJob*"
QT_MOC_LITERAL(30, 300, 1), // "j"
QT_MOC_LITERAL(31, 302, 28), // "moveDataFilesWithMapFinished"
QT_MOC_LITERAL(32, 331, 10), // "downloaded"
QT_MOC_LITERAL(33, 342, 18), // "moveToCompletedDir"
QT_MOC_LITERAL(34, 361, 12) // "emitFinished"

    },
    "bt::TorrentControl\0dataCheckFinished\0"
    "\0update\0pause\0unpause\0start\0stop\0"
    "WaitJob*\0wjob\0updateTracker\0scrapeTracker\0"
    "trackerScrapeDone\0setDataCheckWhenCompleted\0"
    "on\0setMinimumDiskSpace\0Uint32\0m\0"
    "onNewPeer\0Peer*\0p\0onPeerRemoved\0"
    "doChoking\0onIOError\0msg\0updateStats\0"
    "corrupted\0chunk\0moveDataFilesFinished\0"
    "KJob*\0j\0moveDataFilesWithMapFinished\0"
    "downloaded\0moveToCompletedDir\0"
    "emitFinished"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_bt__TorrentControl[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      23,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  129,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,  130,    2, 0x0a /* Public */,
       4,    0,  131,    2, 0x0a /* Public */,
       5,    0,  132,    2, 0x0a /* Public */,
       6,    0,  133,    2, 0x0a /* Public */,
       7,    1,  134,    2, 0x0a /* Public */,
       7,    0,  137,    2, 0x2a /* Public | MethodCloned */,
      10,    0,  138,    2, 0x0a /* Public */,
      11,    0,  139,    2, 0x0a /* Public */,
      12,    0,  140,    2, 0x0a /* Public */,
      13,    1,  141,    2, 0x0a /* Public */,
      15,    1,  144,    2, 0x0a /* Public */,
      18,    1,  147,    2, 0x08 /* Private */,
      21,    1,  150,    2, 0x08 /* Private */,
      22,    0,  153,    2, 0x08 /* Private */,
      23,    1,  154,    2, 0x08 /* Private */,
      25,    0,  157,    2, 0x08 /* Private */,
      26,    1,  158,    2, 0x08 /* Private */,
      28,    1,  161,    2, 0x08 /* Private */,
      31,    1,  164,    2, 0x08 /* Private */,
      32,    1,  167,    2, 0x08 /* Private */,
      33,    0,  170,    2, 0x08 /* Private */,
      34,    0,  171,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8,    9,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   14,
    QMetaType::Void, 0x80000000 | 16,   17,
    QMetaType::Void, 0x80000000 | 19,   20,
    QMetaType::Void, 0x80000000 | 19,   20,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,   24,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 16,   27,
    QMetaType::Void, 0x80000000 | 29,   30,
    QMetaType::Void, 0x80000000 | 29,   30,
    QMetaType::Void, 0x80000000 | 16,   27,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void bt::TorrentControl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TorrentControl *_t = static_cast<TorrentControl *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->dataCheckFinished(); break;
        case 1: _t->update(); break;
        case 2: _t->pause(); break;
        case 3: _t->unpause(); break;
        case 4: _t->start(); break;
        case 5: _t->stop((*reinterpret_cast< WaitJob*(*)>(_a[1]))); break;
        case 6: _t->stop(); break;
        case 7: _t->updateTracker(); break;
        case 8: _t->scrapeTracker(); break;
        case 9: _t->trackerScrapeDone(); break;
        case 10: _t->setDataCheckWhenCompleted((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 11: _t->setMinimumDiskSpace((*reinterpret_cast< Uint32(*)>(_a[1]))); break;
        case 12: _t->onNewPeer((*reinterpret_cast< Peer*(*)>(_a[1]))); break;
        case 13: _t->onPeerRemoved((*reinterpret_cast< Peer*(*)>(_a[1]))); break;
        case 14: _t->doChoking(); break;
        case 15: _t->onIOError((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 16: _t->updateStats(); break;
        case 17: _t->corrupted((*reinterpret_cast< Uint32(*)>(_a[1]))); break;
        case 18: _t->moveDataFilesFinished((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 19: _t->moveDataFilesWithMapFinished((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 20: _t->downloaded((*reinterpret_cast< Uint32(*)>(_a[1]))); break;
        case 21: _t->moveToCompletedDir(); break;
        case 22: _t->emitFinished(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (TorrentControl::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TorrentControl::dataCheckFinished)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject bt::TorrentControl::staticMetaObject = {
    { &TorrentInterface::staticMetaObject, qt_meta_stringdata_bt__TorrentControl.data,
      qt_meta_data_bt__TorrentControl,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *bt::TorrentControl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *bt::TorrentControl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_bt__TorrentControl.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "FilePriorityListener"))
        return static_cast< FilePriorityListener*>(this);
    return TorrentInterface::qt_metacast(_clname);
}

int bt::TorrentControl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TorrentInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void bt::TorrentControl::dataCheckFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
