/****************************************************************************
** Meta object code from reading C++ file 'torrentinterface.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/libktorrent-2.1/src/interfaces/torrentinterface.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'torrentinterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_bt__TorrentInterface_t {
    QByteArrayData data[26];
    char stringdata0[328];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_bt__TorrentInterface_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_bt__TorrentInterface_t qt_meta_stringdata_bt__TorrentInterface = {
    {
QT_MOC_LITERAL(0, 0, 20), // "bt::TorrentInterface"
QT_MOC_LITERAL(1, 21, 8), // "finished"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 21), // "bt::TorrentInterface*"
QT_MOC_LITERAL(4, 53, 2), // "me"
QT_MOC_LITERAL(5, 56, 14), // "stoppedByError"
QT_MOC_LITERAL(6, 71, 3), // "msg"
QT_MOC_LITERAL(7, 75, 15), // "maxRatioChanged"
QT_MOC_LITERAL(8, 91, 18), // "seedingAutoStopped"
QT_MOC_LITERAL(9, 110, 18), // "bt::AutoStopReason"
QT_MOC_LITERAL(10, 129, 6), // "reason"
QT_MOC_LITERAL(11, 136, 16), // "aboutToBeStarted"
QT_MOC_LITERAL(12, 153, 5), // "bool&"
QT_MOC_LITERAL(13, 159, 3), // "ret"
QT_MOC_LITERAL(14, 163, 21), // "missingFilesMarkedDND"
QT_MOC_LITERAL(15, 185, 18), // "corruptedDataFound"
QT_MOC_LITERAL(16, 204, 12), // "diskSpaceLow"
QT_MOC_LITERAL(17, 217, 6), // "toStop"
QT_MOC_LITERAL(18, 224, 14), // "torrentStopped"
QT_MOC_LITERAL(19, 239, 13), // "needDataCheck"
QT_MOC_LITERAL(20, 253, 13), // "statusChanged"
QT_MOC_LITERAL(21, 267, 15), // "chunkDownloaded"
QT_MOC_LITERAL(22, 283, 10), // "bt::Uint32"
QT_MOC_LITERAL(23, 294, 5), // "chunk"
QT_MOC_LITERAL(24, 300, 11), // "updateQueue"
QT_MOC_LITERAL(25, 312, 15) // "runningJobsDone"

    },
    "bt::TorrentInterface\0finished\0\0"
    "bt::TorrentInterface*\0me\0stoppedByError\0"
    "msg\0maxRatioChanged\0seedingAutoStopped\0"
    "bt::AutoStopReason\0reason\0aboutToBeStarted\0"
    "bool&\0ret\0missingFilesMarkedDND\0"
    "corruptedDataFound\0diskSpaceLow\0toStop\0"
    "torrentStopped\0needDataCheck\0statusChanged\0"
    "chunkDownloaded\0bt::Uint32\0chunk\0"
    "updateQueue\0runningJobsDone"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_bt__TorrentInterface[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      14,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      14,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   84,    2, 0x06 /* Public */,
       5,    2,   87,    2, 0x06 /* Public */,
       7,    1,   92,    2, 0x06 /* Public */,
       8,    2,   95,    2, 0x06 /* Public */,
      11,    2,  100,    2, 0x06 /* Public */,
      14,    1,  105,    2, 0x06 /* Public */,
      15,    1,  108,    2, 0x06 /* Public */,
      16,    2,  111,    2, 0x06 /* Public */,
      18,    1,  116,    2, 0x06 /* Public */,
      19,    1,  119,    2, 0x06 /* Public */,
      20,    1,  122,    2, 0x06 /* Public */,
      21,    2,  125,    2, 0x06 /* Public */,
      24,    0,  130,    2, 0x06 /* Public */,
      25,    1,  131,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, QMetaType::QString,    4,    6,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 9,    4,   10,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 12,    4,   13,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, QMetaType::Bool,    4,   17,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 22,    4,   23,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 3,    4,

       0        // eod
};

void bt::TorrentInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TorrentInterface *_t = static_cast<TorrentInterface *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast< bt::TorrentInterface*(*)>(_a[1]))); break;
        case 1: _t->stoppedByError((*reinterpret_cast< bt::TorrentInterface*(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 2: _t->maxRatioChanged((*reinterpret_cast< bt::TorrentInterface*(*)>(_a[1]))); break;
        case 3: _t->seedingAutoStopped((*reinterpret_cast< bt::TorrentInterface*(*)>(_a[1])),(*reinterpret_cast< bt::AutoStopReason(*)>(_a[2]))); break;
        case 4: _t->aboutToBeStarted((*reinterpret_cast< bt::TorrentInterface*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 5: _t->missingFilesMarkedDND((*reinterpret_cast< bt::TorrentInterface*(*)>(_a[1]))); break;
        case 6: _t->corruptedDataFound((*reinterpret_cast< bt::TorrentInterface*(*)>(_a[1]))); break;
        case 7: _t->diskSpaceLow((*reinterpret_cast< bt::TorrentInterface*(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 8: _t->torrentStopped((*reinterpret_cast< bt::TorrentInterface*(*)>(_a[1]))); break;
        case 9: _t->needDataCheck((*reinterpret_cast< bt::TorrentInterface*(*)>(_a[1]))); break;
        case 10: _t->statusChanged((*reinterpret_cast< bt::TorrentInterface*(*)>(_a[1]))); break;
        case 11: _t->chunkDownloaded((*reinterpret_cast< bt::TorrentInterface*(*)>(_a[1])),(*reinterpret_cast< bt::Uint32(*)>(_a[2]))); break;
        case 12: _t->updateQueue(); break;
        case 13: _t->runningJobsDone((*reinterpret_cast< bt::TorrentInterface*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< bt::TorrentInterface* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< bt::TorrentInterface* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< bt::TorrentInterface* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< bt::TorrentInterface* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< bt::TorrentInterface* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< bt::TorrentInterface* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< bt::TorrentInterface* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< bt::TorrentInterface* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< bt::TorrentInterface* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< bt::TorrentInterface* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< bt::TorrentInterface* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< bt::TorrentInterface* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< bt::TorrentInterface* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (TorrentInterface::*_t)(bt::TorrentInterface * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TorrentInterface::finished)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (TorrentInterface::*_t)(bt::TorrentInterface * , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TorrentInterface::stoppedByError)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (TorrentInterface::*_t)(bt::TorrentInterface * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TorrentInterface::maxRatioChanged)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (TorrentInterface::*_t)(bt::TorrentInterface * , bt::AutoStopReason );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TorrentInterface::seedingAutoStopped)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (TorrentInterface::*_t)(bt::TorrentInterface * , bool & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TorrentInterface::aboutToBeStarted)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (TorrentInterface::*_t)(bt::TorrentInterface * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TorrentInterface::missingFilesMarkedDND)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (TorrentInterface::*_t)(bt::TorrentInterface * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TorrentInterface::corruptedDataFound)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (TorrentInterface::*_t)(bt::TorrentInterface * , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TorrentInterface::diskSpaceLow)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (TorrentInterface::*_t)(bt::TorrentInterface * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TorrentInterface::torrentStopped)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (TorrentInterface::*_t)(bt::TorrentInterface * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TorrentInterface::needDataCheck)) {
                *result = 9;
                return;
            }
        }
        {
            typedef void (TorrentInterface::*_t)(bt::TorrentInterface * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TorrentInterface::statusChanged)) {
                *result = 10;
                return;
            }
        }
        {
            typedef void (TorrentInterface::*_t)(bt::TorrentInterface * , bt::Uint32 );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TorrentInterface::chunkDownloaded)) {
                *result = 11;
                return;
            }
        }
        {
            typedef void (TorrentInterface::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TorrentInterface::updateQueue)) {
                *result = 12;
                return;
            }
        }
        {
            typedef void (TorrentInterface::*_t)(bt::TorrentInterface * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TorrentInterface::runningJobsDone)) {
                *result = 13;
                return;
            }
        }
    }
}

const QMetaObject bt::TorrentInterface::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_bt__TorrentInterface.data,
      qt_meta_data_bt__TorrentInterface,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *bt::TorrentInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *bt::TorrentInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_bt__TorrentInterface.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int bt::TorrentInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void bt::TorrentInterface::finished(bt::TorrentInterface * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void bt::TorrentInterface::stoppedByError(bt::TorrentInterface * _t1, QString _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void bt::TorrentInterface::maxRatioChanged(bt::TorrentInterface * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void bt::TorrentInterface::seedingAutoStopped(bt::TorrentInterface * _t1, bt::AutoStopReason _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void bt::TorrentInterface::aboutToBeStarted(bt::TorrentInterface * _t1, bool & _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void bt::TorrentInterface::missingFilesMarkedDND(bt::TorrentInterface * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void bt::TorrentInterface::corruptedDataFound(bt::TorrentInterface * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void bt::TorrentInterface::diskSpaceLow(bt::TorrentInterface * _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void bt::TorrentInterface::torrentStopped(bt::TorrentInterface * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void bt::TorrentInterface::needDataCheck(bt::TorrentInterface * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}

// SIGNAL 10
void bt::TorrentInterface::statusChanged(bt::TorrentInterface * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void bt::TorrentInterface::chunkDownloaded(bt::TorrentInterface * _t1, bt::Uint32 _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void bt::TorrentInterface::updateQueue()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void bt::TorrentInterface::runningJobsDone(bt::TorrentInterface * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
